(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     35961,       1094]
NotebookOptionsPosition[     30672,        902]
NotebookOutlinePosition[     31578,        934]
CellTagsIndexPosition[     31499,        929]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["TemplateBox", "ObjectName",
 CellID->1224892054],

Cell[TextData[{
 Cell["   ", "ModInfo"],
 Cell[BoxData[
  RowBox[{"TemplateBox", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SubscriptBox[
       StyleBox["box", "TI"], "1"], ",", 
      StyleBox[
       SubscriptBox["box", "2"], "TI"], 
      StyleBox[",", "TR"], 
      StyleBox["...", "TR"]}], "}"}], ",", 
    StyleBox["tag", "TI"]}], "]"}]], "InlineFormula"],
 " \[LineSeparator]is a low level box structure which displays as the ",
 Cell[BoxData["DsiplayFunction"], "InlineFormula"],
 " of the template box filled in with the ",
 Cell[BoxData[
  StyleBox[
   SubscriptBox["box", "i"], "TI"]], "InlineFormula"],
 "."
}], "Usage",
 CellChangeTimes->{{3.455262440535139*^9, 3.4552624669068832`*^9}, {
  3.455262514162827*^9, 3.4552625606834497`*^9}, {3.455262601767009*^9, 
  3.45526262286027*^9}, {3.4552648124033527`*^9, 3.455264931213648*^9}},
 CellID->982511436],

Cell[TextData[{
 Cell[BoxData["TemplateBox"], "InlineFormula"],
 " is low-level notebook structure used to represent a parameterized box \
structure. The ",
 Cell[BoxData["DisplayFunction"], "InlineFormula"],
 " option of the ",
 Cell[BoxData["TemplateBox"], "InlineFormula"],
 " is applied to the box arguments to yield a new box structure which is \
displayed."
}], "Notes",
 CellChangeTimes->{{3.4552649687665052`*^9, 3.455264971683963*^9}, {
  3.455265057259535*^9, 3.4552651154476233`*^9}, {3.455265217048744*^9, 
  3.45526529862991*^9}},
 CellID->1265780169],

Cell[TextData[{
 "The ",
 Cell[BoxData["DisplayFunction"], "InlineFormula"],
 " option is normally specified on the style sheet in order that when the \
style sheet changes all displayed instances of the template box change \
unfiormly."
}], "Notes",
 CellChangeTimes->{{3.4552649687665052`*^9, 3.455264971683963*^9}, {
  3.455265057259535*^9, 3.4552651154476233`*^9}, {3.455265217048744*^9, 
  3.455265324567507*^9}, {3.4552653799809*^9, 3.4552654282168503`*^9}, {
  3.455266291442677*^9, 3.455266341897724*^9}, {3.455266423229169*^9, 
  3.4552664435148983`*^9}, {3.4552664922283993`*^9, 3.455266496182414*^9}},
 CellID->1967647048],

Cell[TextData[{
 "If the ",
 StyleBox["tag", "TI"],
 " of the ",
 Cell[BoxData["TemplateBox"], "InlineFormula"],
 " is a string then that style will be used for the ",
 Cell[BoxData["TemplateBox"], "InlineFormula"],
 "."
}], "Notes",
 CellChangeTimes->{{3.4552649687665052`*^9, 3.455264971683963*^9}, {
  3.455265057259535*^9, 3.4552651154476233`*^9}, {3.455265217048744*^9, 
  3.455265324567507*^9}, {3.4552653799809*^9, 3.4552654282168503`*^9}},
 CellID->994293201],

Cell[TextData[{
 "You can write ",
 Cell[BoxData["MakeBoxes"], "InlineFormula"],
 " and ",
 Cell[BoxData["MakeExpression"], "InlineFormula"],
 " rules which use TemplateBoxes in order to define new notations."
}], "Notes",
 CellChangeTimes->{{3.4552649687665052`*^9, 3.455264971683963*^9}, {
  3.455265057259535*^9, 3.4552651154476233`*^9}, {3.455265217048744*^9, 
  3.455265324567507*^9}, {3.4552653799809*^9, 3.4552654282168503`*^9}, {
  3.4552663771796017`*^9, 3.455266406234173*^9}, {3.455266501872468*^9, 
  3.455266532909874*^9}},
 CellID->1143255583]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[GridBox[{
    {
     StyleBox["Examples", "PrimaryExamplesSection"], 
     ButtonBox[
      RowBox[{
       RowBox[{"More", " ", "Examples"}], " ", "\[RightTriangle]"}],
      BaseStyle->"ExtendedExamplesLink",
      ButtonData:>"ExtendedExamples"]}
   }],
  $Line = 0; Null]], "PrimaryExamplesSection",
 CellID->880084151],

Cell[TextData[{
 "The Binomial style is present in the core style sheet so its ",
 Cell[BoxData["DisplayFunction"], "InlineFormula"],
 " is used when assembling the box to display:"
}], "ExampleText",
 CellChangeTimes->{{3.455265465818254*^9, 3.455265477472821*^9}, {
  3.455265514338522*^9, 3.455265565401826*^9}, {3.4552659481338167`*^9, 
  3.455265981141964*^9}, {3.455272232999608*^9, 3.455272251667171*^9}, {
  3.455272296521872*^9, 3.455272431925993*^9}, {3.455272479598219*^9, 
  3.4552725039975653`*^9}},
 CellID->1737826829],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"TemplateBox", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\"\<a\>\"", ",", "\"\<b\>\""}], "}"}], ",", 
    "\"\<Binomial\>\""}], "]"}], "//", "RawBoxes"}]], "Input",
 CellChangeTimes->{{3.455265436501646*^9, 3.455265461698586*^9}, {
  3.4664447783045397`*^9, 3.466444779622179*^9}},
 CellLabel->"In[1]:=",
 CellID->1515571900],

Cell[BoxData[
 TemplateBox[{"a","b"},
  "Binomial"]], "Output",
 CellChangeTimes->{{3.455265456669298*^9, 3.45526546205081*^9}, {
  3.4664447805197573`*^9, 3.466444801925797*^9}},
 CellLabel->"Out[1]=",
 CellID->2142200663]
}, Open  ]],

Cell[TextData[{
 "The actual ",
 Cell[BoxData["DisplayFunction"], "InlineFormula"],
 " of the Binomial style specifed in the core style sheet is ",
 Cell[BoxData[
  RowBox[{"DisplayFunction", " ", "\[Rule]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<(\>\"", ",", " ", 
        RowBox[{"GridBox", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", "#", "}"}], ",", " ", 
           RowBox[{"{", "#2", "}"}]}], "}"}], "]"}], ",", " ", "\"\<)\>\""}], 
       "}"}], "]"}], "&"}], " ", ")"}]}]], "InlineFormula"],
 "."
}], "ExampleText",
 CellChangeTimes->{{3.4552724447853518`*^9, 3.455272458558647*^9}, {
  3.455272526006274*^9, 3.455272542790655*^9}},
 CellID->1280930188],

Cell[TextData[{
 "Many special functions are represented using template boxes. For example, \
the function ",
 StyleBox[ButtonBox["LegendreP",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/LegendreP"], "InlineCode"],
 " is typeset in ",
 StyleBox[ButtonBox["TraditionalForm",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/TraditionalForm"], "InlineCode"],
 " using a ",
 Cell[BoxData["TemplateBox"], "InlineFormula"],
 "."
}], "ExampleText",
 CellChangeTimes->{{3.455265465818254*^9, 3.455265477472821*^9}, {
   3.455265514338522*^9, 3.455265537705809*^9}, {3.4552656097147093`*^9, 
   3.455265750667716*^9}, {3.455265788645203*^9, 3.4552657886464567`*^9}, {
   3.455265845565928*^9, 3.455265857220953*^9}, {3.455265891341674*^9, 
   3.4552659093275757`*^9}, 3.455272553997662*^9},
 CellID->98178470],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"TemplateBox", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\"\<a\>\"", ",", "\"\<b\>\""}], "}"}], ",", 
    "\"\<LegendreP\>\""}], "]"}], "//", "RawBoxes"}]], "Input",
 CellChangeTimes->{{3.455265436501646*^9, 3.455265489602929*^9}, {
  3.466444784655521*^9, 3.4664447858422213`*^9}},
 CellLabel->"In[2]:=",
 CellID->1877915803],

Cell[BoxData[
 TemplateBox[{"a","b"},
  "LegendreP"]], "Output",
 CellChangeTimes->{
  3.455265490125094*^9, {3.466444786358473*^9, 3.466444802053877*^9}},
 CellLabel->"Out[2]=",
 CellID->1403201086]
}, Open  ]],

Cell[TextData[{
 "We can specify the display function of the ",
 Cell[BoxData["TemplateBox"], "InlineFormula"],
 " explicilty but it is usually specified on the style sheet."
}], "ExampleText",
 CellChangeTimes->{{3.455265465818254*^9, 3.455265477472821*^9}, {
   3.455265514338522*^9, 3.455265537705809*^9}, {3.4552656097147093`*^9, 
   3.455265750667716*^9}, {3.455265788645203*^9, 3.4552657886464567`*^9}, {
   3.455265845565928*^9, 3.455265857220953*^9}, {3.455265891341674*^9, 
   3.4552659093275757`*^9}, {3.455266204050437*^9, 3.45526627030488*^9}, 
   3.455272558071027*^9},
 CellID->981325732],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c", "+", 
  RowBox[{"RawBoxes", " ", "@", " ", 
   RowBox[{"TemplateBox", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<a\>\"", ",", "\"\<b\>\""}], "}"}], ",", 
     "\"\<MyCommutator\>\"", ",", 
     RowBox[{"DisplayFunction", ":>", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<[\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{"#1", ",", "\"\<,\>\"", ",", "#2"}], "}"}], "]"}], ",", 
           "\"\<]\>\""}], "}"}], "]"}], "&"}], ")"}]}]}], "]"}]}]}]], "Input",\

 CellChangeTimes->{{3.455265436501646*^9, 3.455265489602929*^9}, {
  3.4552659898409147`*^9, 3.455266020451195*^9}, {3.455266138068184*^9, 
  3.455266215130733*^9}, {3.466444788771882*^9, 3.46644479187857*^9}, {
  3.511810927357038*^9, 3.5118109328347816`*^9}},
 CellLabel->"In[2]:=",
 CellID->467168764],

Cell[BoxData[
 RowBox[{"c", "+", 
  TemplateBox[{"a","b"},
   "MyCommutator",
   DisplayFunction:>(RowBox[{"[", 
      RowBox[{#, ",", #2}], "]"}]& )]}]], "Output",
 CellChangeTimes->{
  3.455265490125094*^9, {3.455266151981196*^9, 3.455266183938179*^9}, 
   3.455266215795377*^9, 3.466444802175557*^9, 3.5118108704817543`*^9, {
   3.51181091753857*^9, 3.511810933261881*^9}},
 CellLabel->"Out[2]=",
 CellID->970676096]
}, Open  ]],

Cell["TemplateBoxes can be nested to any level", "ExampleText",
 CellChangeTimes->{{3.455265465818254*^9, 3.455265477472821*^9}, {
  3.455265514338522*^9, 3.455265537705809*^9}, {3.4552656097147093`*^9, 
  3.455265750667716*^9}, {3.455265788645203*^9, 3.4552657886464567`*^9}, {
  3.455265845565928*^9, 3.455265857220953*^9}, {3.455265891341674*^9, 
  3.4552659093275757`*^9}, {3.455266204050437*^9, 3.45526627030488*^9}, {
  3.455269100711931*^9, 3.455269108748752*^9}},
 CellID->1112495170],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"TemplateBox", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"TemplateBox", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<n\>\"", ",", "\"\<x\>\""}], "}"}], ",", 
        "\"\<LegendreP\>\""}], "]"}], ",", "\"\<b\>\""}], "}"}], ",", 
    "\"\<Binomial\>\""}], "]"}], "//", "RawBoxes"}]], "Input",
 CellChangeTimes->{{3.4552691148379707`*^9, 3.455269177503447*^9}, 
   3.466444794044012*^9},
 CellLabel->"In[4]:=",
 CellID->316304785],

Cell[BoxData[
 TemplateBox[{TemplateBox[{"n", "x"}, "LegendreP"],"b"},
  "Binomial"]], "Output",
 CellChangeTimes->{3.455269133627618*^9, 3.455269179265856*^9, 
  3.466444802292227*^9},
 CellLabel->"Out[4]=",
 CellID->370502765]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["More Examples", "ExtendedExamplesSection",
 CellTags->"ExtendedExamples",
 CellID->1854448968],

Cell[BoxData[
 InterpretationBox[Cell["Scope", "ExampleSection"],
  $Line = 0; Null]], "ExampleSection",
 CellID->1293636265],

Cell[BoxData[
 InterpretationBox[Cell["Generalizations & Extensions", "ExampleSection"],
  $Line = 0; Null]], "ExampleSection",
 CellID->1020263627],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["Options", "ExampleSection"],
  $Line = 0; Null]], "ExampleSection",
 CellID->2061341341],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["DisplayFunction", "ExampleSubsection"],
  $Line = 0; Null]], "ExampleSubsection",
 CellChangeTimes->{{3.455266821715624*^9, 3.455266847969316*^9}},
 CellID->391659043],

Cell[TextData[{
 "If we specify the ",
 Cell[BoxData["DisplayFunction"], "InlineFormula"],
 " option explicilty in the ",
 Cell[BoxData["TemplateBox"], "InlineFormula"],
 " than this overrides any ",
 Cell[BoxData["DisplayFunction"], "InlineFormula"],
 " inherited from the StyleSheet."
}], "ExampleText",
 CellChangeTimes->{{3.455265465818254*^9, 3.455265477472821*^9}, {
  3.455265514338522*^9, 3.455265537705809*^9}, {3.4552656097147093`*^9, 
  3.455265750667716*^9}, {3.455265788645203*^9, 3.4552657886464567`*^9}, {
  3.455265845565928*^9, 3.455265857220953*^9}, {3.455265891341674*^9, 
  3.4552659093275757`*^9}, {3.455266204050437*^9, 3.45526627030488*^9}, {
  3.455266648887377*^9, 3.4552666859091387`*^9}, {3.455270149707335*^9, 
  3.455270156863557*^9}},
 CellID->1160393772],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c", "+", 
  RowBox[{"RawBoxes", " ", "@", " ", 
   RowBox[{"TemplateBox", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<a\>\"", ",", "\"\<b\>\""}], "}"}], ",", 
     "\"\<Binomial\>\""}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.455265436501646*^9, 3.455265489602929*^9}, {
  3.4552659898409147`*^9, 3.455266020451195*^9}, {3.455266138068184*^9, 
  3.455266215130733*^9}, {3.455266689158915*^9, 3.455266706558825*^9}, {
  3.4664447948375597`*^9, 3.466444818656506*^9}},
 CellLabel->"In[1]:=",
 CellID->1312002844],

Cell[BoxData[
 RowBox[{"c", "+", 
  TemplateBox[{"a","b"},
   "Binomial"]}]], "Output",
 CellChangeTimes->{{3.455266701266007*^9, 3.455266707037689*^9}, {
  3.466444802593687*^9, 3.4664448191185083`*^9}},
 CellLabel->"Out[1]=",
 CellID->200225340]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c", "+", 
  RowBox[{"RawBoxes", " ", "@", " ", 
   RowBox[{"TemplateBox", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<a\>\"", ",", "\"\<b\>\""}], "}"}], ",", "\"\<Binomial\>\"",
      ",", 
     RowBox[{"DisplayFunction", ":>", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<[\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{"#1", ",", "\"\<,\>\"", ",", "#2"}], "}"}], "]"}], ",", 
           "\"\<]\>\""}], "}"}], "]"}], "&"}], ")"}]}]}], "]"}]}]}]], "Input",\

 CellChangeTimes->{{3.455265436501646*^9, 3.455265489602929*^9}, {
  3.4552659898409147`*^9, 3.455266020451195*^9}, {3.455266138068184*^9, 
  3.455266215130733*^9}, {3.455266689158915*^9, 3.455266691734907*^9}, {
  3.466444795573522*^9, 3.466444826770413*^9}},
 CellLabel->"In[2]:=",
 CellID->1439127597],

Cell[BoxData[
 RowBox[{"c", "+", 
  TemplateBox[{"a","b"},
   "Binomial",
   DisplayFunction:>(RowBox[{"[", 
      RowBox[{#, ",", #2}], "]"}]& )]}]], "Output",
 CellChangeTimes->{
  3.455265490125094*^9, {3.455266151981196*^9, 3.455266183938179*^9}, 
   3.455266215795377*^9, 3.4552666923768167`*^9, {3.466444802709339*^9, 
   3.466444827525395*^9}},
 CellLabel->"Out[2]=",
 CellID->80414531]
}, Open  ]],

Cell[TextData[{
 "The result of applying the ",
 Cell[BoxData["DisplayFunction"], "InlineFormula"],
 " to the box arguments must yield a valid box structure or the box will not \
be displayed correctly"
}], "ExampleText",
 CellChangeTimes->{{3.455265465818254*^9, 3.455265477472821*^9}, {
   3.455265514338522*^9, 3.455265537705809*^9}, {3.4552656097147093`*^9, 
   3.455265750667716*^9}, {3.455265788645203*^9, 3.4552657886464567`*^9}, {
   3.455265845565928*^9, 3.455265857220953*^9}, {3.455265891341674*^9, 
   3.4552659093275757`*^9}, {3.455266204050437*^9, 3.45526627030488*^9}, {
   3.455266648887377*^9, 3.4552666859091387`*^9}, {3.455266732646995*^9, 
   3.4552667913660183`*^9}, 3.4552701606167507`*^9},
 CellID->1420388455],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"TemplateBox", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\"\<a\>\"", ",", "\"\<b\>\""}], "}"}], ",", 
    "\"\<MyCommutator\>\"", ",", 
    RowBox[{"DisplayFunction", ":>", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<[\>\"", ",", 
          RowBox[{"foo", "[", 
           RowBox[{"{", 
            RowBox[{"#1", ",", "\"\<,\>\"", ",", "#2"}], "}"}], "]"}], ",", 
          "\"\<]\>\""}], "}"}], "]"}], "&"}], ")"}]}]}], "]"}], "//", 
  "RawBoxes"}]], "Input",
 CellChangeTimes->{{3.455265436501646*^9, 3.455265489602929*^9}, {
   3.4552659898409147`*^9, 3.455266020451195*^9}, {3.455266138068184*^9, 
   3.455266215130733*^9}, {3.455266689158915*^9, 3.455266691734907*^9}, {
   3.455266771489648*^9, 3.455266802312091*^9}, 3.4664447961745033`*^9},
 CellLabel->"In[3]:=",
 CellID->1040543133],

Cell[BoxData[
 TemplateBox[{"a","b"},
  "MyCommutator",
  DisplayFunction:>(RowBox[{"[", 
     $CellContext`foo[{#, ",", #2}], "]"}]& )]], "Output",
 CellChangeTimes->{3.4552667723776293`*^9, 3.466444802825918*^9, 
  3.4664448332966347`*^9},
 CellLabel->"Out[3]=",
 CellID->759808554]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["InterpretationFunction", "ExampleSubsection"],
  $Line = 0; Null]], "ExampleSubsection",
 CellChangeTimes->{{3.455266821715624*^9, 3.455266847969316*^9}, {
  3.455268856695912*^9, 3.455268860581039*^9}},
 CellID->209107802],

Cell[TextData[{
 "The ",
 Cell[BoxData["InterpretationFunction"], "InlineFormula"],
 " must yield a parsable box structure when applied to the ",
 Cell[BoxData["TemplateBox"], "InlineFormula"],
 " arguments. The assmebled box structure is used when sending the boxes to \
the kernel for evaluation and for copying and pasting into external \
applications."
}], "ExampleText",
 CellChangeTimes->{{3.455269466913596*^9, 3.455269516360799*^9}, {
  3.455269855247507*^9, 3.455269894740341*^9}, {3.455270139638022*^9, 
  3.455270143218379*^9}, {3.455270174825444*^9, 3.4552702207275248`*^9}},
 CellID->1055683320],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RawBoxes", " ", "@", " ", 
  RowBox[{"TemplateBox", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\"\<a\>\"", ",", "\"\<b\>\""}], "}"}], ",", 
    "\"\<MyCommutator\>\"", ",", "\[IndentingNewLine]", 
    RowBox[{"InterpretationFunction", ":>", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<LieBracket\>\"", ",", "\"\<[\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"#1", ",", "\"\<,\>\"", ",", "#2"}], "}"}], "]"}], ",", 
          "\"\<]\>\""}], "}"}], "]"}], "&"}], ")"}]}], ",", 
    RowBox[{"DisplayFunction", ":>", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<[\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"#1", ",", "\"\<,\>\"", ",", "#2"}], "}"}], "]"}], ",", 
          "\"\<]\>\""}], "}"}], "]"}], "&"}], ")"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Tooltip", "\[RuleDelayed]", "Automatic"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.455269432411167*^9, 3.455269441514142*^9}, {
   3.455269929136115*^9, 3.455269979030677*^9}, 3.466444796894658*^9, {
   3.466444838001911*^9, 3.466444838601605*^9}},
 CellLabel->"In[4]:=",
 CellID->466284301],

Cell[BoxData[
 TemplateBox[{"a","b"},
  "MyCommutator",
  DisplayFunction:>(RowBox[{"[", 
     RowBox[{#, ",", #2}], "]"}]& ),
  InterpretationFunction:>(RowBox[{"LieBracket", "[", 
     RowBox[{#, ",", #2}], "]"}]& ),
  Tooltip:>Automatic]], "Output",
 CellChangeTimes->{3.455270028153655*^9, 3.4664448031714163`*^9, 
  3.466444839001422*^9},
 CellLabel->"Out[4]=",
 CellID->1164602016]
}, Open  ]],

Cell["This same structure used as input evaluates to LieBracket.", \
"ExampleText",
 CellChangeTimes->{{3.4552699854934483`*^9, 3.455270024845697*^9}},
 CellID->2120392989],

Cell[CellGroupData[{

Cell[BoxData[
 TemplateBox[{"a","b"},
  "MyCommutator",
  DisplayFunction:>(RowBox[{"[", 
     RowBox[{#, ",", #2}], "]"}]& ),
  InterpretationFunction:>(RowBox[{"LieBracket", "[", 
     RowBox[{#, ",", #2}], "]"}]& ),
  Tooltip:>Automatic]], "Input",
 CellChangeTimes->{{3.455269980485043*^9, 3.4552699810546713`*^9}},
 CellLabel->"In[2]:=",
 CellID->1916488224],

Cell[BoxData[
 RowBox[{"LieBracket", "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Output",
 CellChangeTimes->{3.455269981497941*^9, 3.455270015809987*^9, 
  3.466444803293335*^9},
 CellLabel->"Out[2]=",
 CellID->1208217552]
}, Open  ]],

Cell[TextData[{
 "If the ",
 Cell[BoxData["InterpretationFunction"], "InlineFormula"],
 " option is ",
 Cell[BoxData["Automatic"], "InlineFormula"],
 " then the name of the ",
 StyleBox["tag", "TI"],
 " is used as the function head of the box structure sent to the kernel."
}], "ExampleText",
 CellChangeTimes->{{3.45527003264156*^9, 3.455270129473075*^9}},
 CellID->1360290328],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RawBoxes", " ", "@", " ", 
  RowBox[{"TemplateBox", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\"\<a\>\"", ",", "\"\<b\>\""}], "}"}], ",", 
    "\"\<MyCommutator\>\"", ",", "\[IndentingNewLine]", 
    RowBox[{"InterpretationFunction", "\[RuleDelayed]", "Automatic"}], ",", 
    RowBox[{"DisplayFunction", ":>", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<[\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"#1", ",", "\"\<,\>\"", ",", "#2"}], "}"}], "]"}], ",", 
          "\"\<]\>\""}], "}"}], "]"}], "&"}], ")"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Tooltip", "\[RuleDelayed]", "Automatic"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.455269432411167*^9, 3.455269441514142*^9}, {
   3.455269929136115*^9, 3.455269979030677*^9}, {3.455270261591806*^9, 
   3.455270263738207*^9}, 3.466444797411603*^9, {3.4664448424096212`*^9, 
   3.466444843120635*^9}},
 CellLabel->"In[5]:=",
 CellID->2099513412],

Cell[BoxData[
 TemplateBox[{"a","b"},
  "MyCommutator",
  DisplayFunction:>(RowBox[{"[", 
     RowBox[{#, ",", #2}], "]"}]& ),
  InterpretationFunction:>Automatic,
  Tooltip:>Automatic]], "Output",
 CellChangeTimes->{3.4552702916559353`*^9, 3.46644480342152*^9, 
  3.466444843621686*^9},
 CellLabel->"Out[5]=",
 CellID->1300124154]
}, Open  ]],

Cell["This same structure used as input evaluates to MyCommutator.", \
"ExampleText",
 CellChangeTimes->{{3.4552699854934483`*^9, 3.455270024845697*^9}, {
  3.455270309602051*^9, 3.455270312248477*^9}},
 CellID->904171040],

Cell[CellGroupData[{

Cell[BoxData[
 TemplateBox[{"a","b"},
  "MyCommutator",
  DisplayFunction:>(RowBox[{"[", 
     RowBox[{#, ",", #2}], "]"}]& ),
  InterpretationFunction:>Automatic,
  Tooltip:>Automatic]], "Input",
 CellChangeTimes->{{3.455270266439843*^9, 3.455270266921453*^9}},
 CellLabel->"In[4]:=",
 CellID->1218111627],

Cell[BoxData[
 RowBox[{"MyCommutator", "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Output",
 CellChangeTimes->{{3.455270268688456*^9, 3.45527028905619*^9}, 
   3.466444803554677*^9},
 CellLabel->"Out[4]=",
 CellID->828565640]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["Tooltip", "ExampleSubsection"],
  $Line = 0; Null]], "ExampleSubsection",
 CellChangeTimes->{{3.455266821715624*^9, 3.455266861113696*^9}},
 CellID->576157646],

Cell["\<\
You can specify the tooltip that will be displayed when the mouse hovers over \
a template box.\
\>", "ExampleText",
 CellChangeTimes->{{3.455265465818254*^9, 3.455265477472821*^9}, {
  3.455265514338522*^9, 3.455265537705809*^9}, {3.4552656097147093`*^9, 
  3.455265750667716*^9}, {3.455265788645203*^9, 3.4552657886464567`*^9}, {
  3.455265845565928*^9, 3.455265857220953*^9}, {3.455265891341674*^9, 
  3.4552659093275757`*^9}, {3.455266204050437*^9, 3.45526627030488*^9}, {
  3.455266648887377*^9, 3.4552666859091387`*^9}, {3.455266732646995*^9, 
  3.4552667913660183`*^9}, {3.455268601824115*^9, 3.4552687195689783`*^9}},
 CellID->719647019],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"TemplateBox", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\"\<a\>\"", ",", "\"\<b\>\""}], "}"}], ",", "\"\<Binomial\>\"", 
    ",", 
    RowBox[{"Tooltip", "\[RuleDelayed]", "\"\<a vacuous tooltip\>\""}]}], 
   "]"}], "//", "RawBoxes"}]], "Input",
 CellChangeTimes->{{3.455265436501646*^9, 3.455265489602929*^9}, {
   3.4552659898409147`*^9, 3.455266020451195*^9}, {3.455266138068184*^9, 
   3.455266215130733*^9}, {3.455266689158915*^9, 3.455266691734907*^9}, {
   3.455266771489648*^9, 3.455266802312091*^9}, {3.455267067533266*^9, 
   3.455267072042939*^9}, {3.4552685270872383`*^9, 3.455268543225519*^9}, {
   3.4552685801237793`*^9, 3.455268591393609*^9}, {3.455268668979788*^9, 
   3.455268677162553*^9}, {3.455268729315318*^9, 3.4552687579708347`*^9}, 
   3.466444798094223*^9},
 CellLabel->"In[1]:=",
 CellID->479548429],

Cell[BoxData[
 TemplateBox[{"a","b"},
  "Binomial",
  Tooltip:>"a vacuous tooltip"]], "Output",
 CellChangeTimes->{
  3.4552685441701117`*^9, 3.455268592860611*^9, 3.455268677897192*^9, {
   3.45526874521883*^9, 3.455268773492237*^9}, 3.466444803760366*^9},
 CellLabel->"Out[1]=",
 CellID->1418744332]
}, Open  ]],

Cell[TextData[{
 "If you specify the option ",
 Cell[BoxData["Tooltip"], "InlineFormula"],
 " \[Rule] ",
 Cell[BoxData["Automatic"], "InlineFormula"],
 " then a tooltip will be generated from the name of the tag of the ",
 Cell[BoxData["TemplateBox"], "InlineFormula"],
 "."
}], "ExampleText",
 CellChangeTimes->{{3.455265465818254*^9, 3.455265477472821*^9}, {
  3.455265514338522*^9, 3.455265537705809*^9}, {3.4552656097147093`*^9, 
  3.455265750667716*^9}, {3.455265788645203*^9, 3.4552657886464567`*^9}, {
  3.455265845565928*^9, 3.455265857220953*^9}, {3.455265891341674*^9, 
  3.4552659093275757`*^9}, {3.455266204050437*^9, 3.45526627030488*^9}, {
  3.455266648887377*^9, 3.4552666859091387`*^9}, {3.455266732646995*^9, 
  3.4552667913660183`*^9}, {3.455268601824115*^9, 3.455268660016431*^9}, {
  3.4552688051643677`*^9, 3.4552688199342737`*^9}},
 CellID->477791999],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"TemplateBox", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\"\<X\>\"", ",", "\"\<b\>\""}], "}"}], ",", 
    "\"\<LieDerivative\>\"", ",", 
    RowBox[{"DisplayFunction", ":>", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"SubscriptBox", "[", 
           RowBox[{"\"\<\[ScriptCapitalL]\>\"", ",", "#1"}], "]"}], ",", 
          "#2"}], "}"}], "]"}], "&"}], ")"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Tooltip", "\[RuleDelayed]", "Automatic"}]}], "]"}], "//", 
  "RawBoxes"}]], "Input",
 CellChangeTimes->{{3.455265436501646*^9, 3.455265489602929*^9}, {
   3.4552659898409147`*^9, 3.455266020451195*^9}, {3.455266138068184*^9, 
   3.455266215130733*^9}, {3.455266689158915*^9, 3.455266691734907*^9}, {
   3.455266771489648*^9, 3.455266802312091*^9}, {3.455267067533266*^9, 
   3.455267072042939*^9}, {3.4552685270872383`*^9, 3.455268543225519*^9}, {
   3.4552685801237793`*^9, 3.455268591393609*^9}, 3.466444798764578*^9},
 CellLabel->"In[2]:=",
 CellID->808771060],

Cell[BoxData[
 TemplateBox[{"X","b"},
  "LieDerivative",
  DisplayFunction:>(RowBox[{
     SubscriptBox["\[ScriptCapitalL]", #], #2}]& ),
  Tooltip:>Automatic]], "Output",
 CellChangeTimes->{3.4552685441701117`*^9, 3.455268592860611*^9, 
  3.4552703466527853`*^9, 3.4664448038767557`*^9},
 CellLabel->"Out[2]=",
 CellID->1325055283]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[Cell["SyntaxForm", "ExampleSubsection"],
  $Line = 0; Null]], "ExampleSubsection",
 CellChangeTimes->{{3.455266821715624*^9, 3.455266824579352*^9}},
 CellID->1295379749],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox["SyntaxForm",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/SyntaxForm"]], "InlineFormula"],
 " is specified as a string containing an operator whose precedence level is \
the same as that of the contents of the ",
 Cell[BoxData[
  ButtonBox["InterpretationBox",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/InterpretationBox"]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  ButtonBox["TagBox",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/TagBox"]], "InlineFormula"],
 ". For example, ",
 Cell[BoxData[
  RowBox[{"SyntaxForm", " ", "->", " ", "\"\<*\>\""}]], "InlineFormula"],
 ". You can also distinguish the infix and prefix form of an operator, for \
example, by setting ",
 Cell[BoxData[
  ButtonBox["SyntaxForm",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/SyntaxForm"]], "InlineFormula"],
 " to ",
 Cell[BoxData["\"\<\!\(\*
StyleBox[\"a\", \"TI\"]\\\  + \\\ \*
StyleBox[\"b\", \"TI\"]\)\>\""], "InlineFormula"],
 " and ",
 Cell[BoxData["\"\<+ a\>\""], "InlineFormula"],
 ", respectively. "
}], "ExampleText",
 CellChangeTimes->{{3.455270544188138*^9, 3.4552705564589977`*^9}},
 CellID->2144516417],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"TemplateBox", "[", 
   RowBox[{
    RowBox[{"{", "\"\<x\>\"", "}"}], ",", "\"\<DerivativeOperator\>\"", ",", 
    RowBox[{"DisplayFunction", ":>", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"FractionBox", "[", 
        RowBox[{"\"\<\[PartialD]\>\"", ",", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<\[PartialD]\>\"", ",", "#1"}], "}"}], "]"}]}], "]"}], 
       "&"}], ")"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"SyntaxForm", "\[Rule]", "\"\<\[PartialD]\>\""}]}], "]"}], "//", 
  "RawBoxes"}]], "Input",
 CellChangeTimes->{{3.455270580921596*^9, 3.4552705832206707`*^9}, {
   3.45527061768602*^9, 3.455270649157442*^9}, 3.466444799614003*^9},
 CellLabel->"In[1]:=",
 CellID->1669372918],

Cell[BoxData[
 TemplateBox[{"x"},
  "DerivativeOperator",
  DisplayFunction:>(FractionBox["\[PartialD]", 
    RowBox[{"\[PartialD]", #}]]& ),
  SyntaxForm->"\[PartialD]"]], "Output",
 CellChangeTimes->{3.455270811839872*^9, 3.4664448042105627`*^9},
 CellLabel->"Out[1]=",
 CellID->798721991]
}, Open  ]],

Cell[TextData[{
 "possible values for the ",
 Cell[BoxData["SyntaxForm"], "InlineFormula"],
 " option include:"
}], "ExampleText",
 CellChangeTimes->{{3.455271182875094*^9, 3.455271183329496*^9}, {
  3.455271295633976*^9, 3.455271311033372*^9}},
 CellID->280482333],

Cell[BoxData[GridBox[{
   {Cell["      ", "ModInfo"], "\"\<*\>\"", Cell[
    "group as the operator times", "TableText"]},
   {Cell["      ", "ModInfo"], "\"\<fish\>\"", Cell[
    "group as a symbol", "TableText"]},
   {Cell["      ", "ModInfo"], "\"\<foo+baz\>\"", Cell[
    "group as an infix plus operator", "TableText"]},
   {Cell["      ", "ModInfo"], "\"\<\[ForAll]\>\"", Cell[
    "group as a for all operator", "TableText"]},
   {Cell["      ", "ModInfo"], "\"\<\[Integral]\>\"", Cell[
    "group as an integrate operator", "TableText"]},
   {Cell["      ", "ModInfo"], "\"\<\[Union] bar\>\"", Cell[
    "group as a prefix union operator", "TableText"]},
   {Cell["      ", "ModInfo"], "\"\< \>\"", Cell[
    "group as white space", "TableText"]}
  }]], "2ColumnTableMod",
 CellChangeTimes->{{3.455271054822773*^9, 3.455271209288105*^9}, {
  3.4552712643707523`*^9, 3.455271277906639*^9}},
 CellID->426012433]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"Preview",
WindowSize->{1028, 1146},
WindowMargins->{{25, Automatic}, {Automatic, 0}},
CellContext->"Global`",
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 16, \
2011)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> 
     FrontEnd`FileName[{"Wolfram"}, "FunctionPageStyles.nb", 
       CharacterEncoding -> "UTF-8"]]]}, Visible -> False, FrontEndVersion -> 
  "9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 16, 2011)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "ExtendedExamples"->{
  Cell[10753, 322, 100, 2, 53, "ExtendedExamplesSection",
   CellTags->"ExtendedExamples",
   CellID->1854448968]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"ExtendedExamples", 31360, 922}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 54, 1, 62, "ObjectName",
 CellID->1224892054],
Cell[624, 25, 881, 25, 86, "Usage",
 CellID->982511436],
Cell[1508, 52, 564, 13, 53, "Notes",
 CellID->1265780169],
Cell[2075, 67, 633, 12, 38, "Notes",
 CellID->1967647048],
Cell[2711, 81, 467, 12, 24, "Notes",
 CellID->994293201],
Cell[3181, 95, 557, 12, 38, "Notes",
 CellID->1143255583]
}, Open  ]],
Cell[CellGroupData[{
Cell[3775, 112, 356, 11, 69, "PrimaryExamplesSection",
 CellID->880084151],
Cell[4134, 125, 533, 10, 34, "ExampleText",
 CellID->1737826829],
Cell[CellGroupData[{
Cell[4692, 139, 367, 10, 23, "Input",
 CellID->1515571900],
Cell[5062, 151, 223, 6, 38, "Output",
 CellID->2142200663]
}, Open  ]],
Cell[5300, 160, 750, 21, 35, "ExampleText",
 CellID->1280930188],
Cell[6053, 183, 802, 19, 34, "ExampleText",
 CellID->98178470],
Cell[CellGroupData[{
Cell[6880, 206, 368, 10, 23, "Input",
 CellID->1877915803],
Cell[7251, 218, 199, 6, 22, "Output",
 CellID->1403201086]
}, Open  ]],
Cell[7465, 227, 602, 11, 34, "ExampleText",
 CellID->981325732],
Cell[CellGroupData[{
Cell[8092, 242, 922, 24, 39, "Input",
 CellID->467168764],
Cell[9017, 268, 419, 11, 22, "Output",
 CellID->970676096]
}, Open  ]],
Cell[9451, 282, 492, 7, 20, "ExampleText",
 CellID->1112495170],
Cell[CellGroupData[{
Cell[9968, 293, 505, 15, 39, "Input",
 CellID->316304785],
Cell[10476, 310, 228, 6, 40, "Output",
 CellID->370502765]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10753, 322, 100, 2, 53, "ExtendedExamplesSection",
 CellTags->"ExtendedExamples",
 CellID->1854448968],
Cell[10856, 326, 125, 3, 31, "ExampleSection",
 CellID->1293636265],
Cell[10984, 331, 148, 3, 19, "ExampleSection",
 CellID->1020263627],
Cell[CellGroupData[{
Cell[11157, 338, 127, 3, 19, "ExampleSection",
 CellID->2061341341],
Cell[CellGroupData[{
Cell[11309, 345, 206, 4, 21, "ExampleSubsection",
 CellID->391659043],
Cell[11518, 351, 785, 16, 35, "ExampleText",
 CellID->1160393772],
Cell[CellGroupData[{
Cell[12328, 371, 550, 13, 23, "Input",
 CellID->1312002844],
Cell[12881, 386, 247, 7, 38, "Output",
 CellID->200225340]
}, Open  ]],
Cell[CellGroupData[{
Cell[13165, 398, 918, 24, 39, "Input",
 CellID->1439127597],
Cell[14086, 424, 393, 11, 22, "Output",
 CellID->80414531]
}, Open  ]],
Cell[14494, 438, 733, 13, 34, "ExampleText",
 CellID->1420388455],
Cell[CellGroupData[{
Cell[15252, 455, 900, 23, 54, "Input",
 CellID->1040543133],
Cell[16155, 480, 284, 8, 30, "Output",
 CellID->759808554]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[16488, 494, 262, 5, 21, "ExampleSubsection",
 CellID->209107802],
Cell[16753, 501, 608, 12, 48, "ExampleText",
 CellID->1055683320],
Cell[CellGroupData[{
Cell[17386, 517, 1313, 33, 84, "Input",
 CellID->466284301],
Cell[18702, 552, 387, 11, 22, "Output",
 CellID->1164602016]
}, Open  ]],
Cell[19104, 566, 172, 3, 20, "ExampleText",
 CellID->2120392989],
Cell[CellGroupData[{
Cell[19301, 573, 363, 10, 23, "Input",
 CellID->1916488224],
Cell[19667, 585, 220, 6, 22, "Output",
 CellID->1208217552]
}, Open  ]],
Cell[19902, 594, 378, 10, 34, "ExampleText",
 CellID->1360290328],
Cell[CellGroupData[{
Cell[20305, 608, 1051, 25, 69, "Input",
 CellID->2099513412],
Cell[21359, 635, 331, 10, 22, "Output",
 CellID->1300124154]
}, Open  ]],
Cell[21705, 648, 222, 4, 20, "ExampleText",
 CellID->904171040],
Cell[CellGroupData[{
Cell[21952, 656, 306, 9, 23, "Input",
 CellID->1218111627],
Cell[22261, 667, 223, 6, 22, "Output",
 CellID->828565640]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[22533, 679, 198, 4, 21, "ExampleSubsection",
 CellID->576157646],
Cell[22734, 685, 655, 11, 20, "ExampleText",
 CellID->719647019],
Cell[CellGroupData[{
Cell[23414, 700, 869, 18, 39, "Input",
 CellID->479548429],
Cell[24286, 720, 301, 8, 38, "Output",
 CellID->1418744332]
}, Open  ]],
Cell[24602, 731, 873, 17, 35, "ExampleText",
 CellID->477791999],
Cell[CellGroupData[{
Cell[25500, 752, 1089, 25, 54, "Input",
 CellID->808771060],
Cell[26592, 779, 332, 9, 22, "Output",
 CellID->1325055283]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26973, 794, 202, 4, 21, "ExampleSubsection",
 CellID->1295379749],
Cell[27178, 800, 1163, 34, 63, "ExampleText",
 CellID->2144516417],
Cell[CellGroupData[{
Cell[28366, 838, 772, 19, 54, "Input",
 CellID->1669372918],
Cell[29141, 859, 291, 8, 42, "Output",
 CellID->798721991]
}, Open  ]],
Cell[29447, 870, 265, 7, 21, "ExampleText",
 CellID->280482333],
Cell[29715, 879, 917, 18, 119, "2ColumnTableMod",
 CellID->426012433]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
